@@ -202,9 +202,9 @@ def pascalCaseToTitle(name: str, addSpaces=True) -> str:
 
 # Make a class for reference persistence
 _nameFmtType = t.Callable[[str], str]
-class _NameFormatter:
-  def __init__(self):
-    self._formatter = pascalCaseToTitle
+class NameFormatter:
+  def __init__(self, formatter: t.Callable[[str], str]=pascalCaseToTitle):
+    self._formatter = formatter
 
   def __call__(self, inStr: str):
     return self._formatter(inStr)
@@ -216,7 +216,7 @@ class _NameFormatter:
     yield
     self._formatter = oldFmt
 
-nameFormatter = _NameFormatter()
+nameFormatter = NameFormatter()
 
 
 def clsNameOrGroup(cls: t.Union[type, t.Any]):
