@@ -251,10 +251,6 @@ class ProcGroupParameter(parameterTypes.GroupParameter):
       for chParam in filter(lambda el: isinstance(el, ProcGroupParameter), self):
         chParam.setOpts(enabled=enabled)
 
-class _DummySignal:
-  def connect(self, *args): pass
-  def disconnect(self, *args): pass
-
 # WidgetParameterItem is not a QObject, so it can't emit signals. Use a dummy class instead
 class _Emitter(QtCore.QObject):
   sigChanging = QtCore.Signal(object)
