@@ -106,12 +106,17 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
       shcValue = opts.value
 
     proc = editor.registerFunc(func, **kwargs)
+    returnParam = kwargs.get('returnParam', False)
+    if returnParam:
+      proc, param = proc
     act = parentMenu.addAction(proc.name)
     if ShortcutParameter.REGISTRY and shcValue and self._makeMenuShortcuts:
       ShortcutParameter.REGISTRY.registerAction(opts, act,
                                                 namePath=(owner.__groupingName__,))
 
     act.triggered.connect(proc)
+    if returnParam:
+      return proc, param
     return proc
 
   def registerPopoutFuncs(self, funcList: Sequence[Callable], nameList: Sequence[str]=None, groupName:str=None, btnOpts: PrjParam=None):
