@@ -239,6 +239,28 @@ class PopupLineEditor(QtWidgets.QLineEdit):
       self.completer().setCompletionPrefix('')
 
 
+class HoverScatter(pg.ScatterPlotItem):
+  def __init__(self, *args, **kargs):
+    super().__init__(*args, **kargs)
+
+  def hoverEvent(self, ev: QtGui.QHoverEvent):
+    if not hasattr(ev, '_scenePos'): return
+    pts = self.pointsAt(ev.pos())
+    if len(pts) > 0:
+      pt = pts[-1]
+      data = pt.data()
+      if isinstance(data, t.Callable):
+        # Data hasn't been evaluated yet
+        try:
+          data = data()
+          pt.setData(data)
+        except Exception as ex:
+          data = None
+    else:
+      data = None
+    self.setToolTip(data)
+
+
 class _DEFAULT_OWNER: pass
 """None is a valid owner, so create a sentinel that's not valid"""
 btnCallable = t.Callable[[PrjParam], t.Any]
@@ -1097,4 +1119,11 @@ class PandasTableModel(QtCore.QAbstractTableModel):
         try:
           self.df[col] = self.df[col].astype(idealType)
         except (TypeError, ValueError):
-          continue
\ No newline at end of file
+          continue
+
+
+class DummySignal:
+  """Useful for spoofing a qt connection that doesn't do anything"""
+  def connect(self, *args): pass
+  def disconnect(self, *args): pass
+  def emit(self, *args): pass
\ No newline at end of file
